import pandas as pd
from scipy.stats import entropy

import sys
sys.path.insert(1, '/workspaces/rapids/calculatingfeatures')
from CalculatingFeatures.helper_functions import convert1DEmpaticaToArray, convertInputInto2d, gsrFeatureNames
from CalculatingFeatures.calculate_features import calculateFeatures

pd.set_option('display.max_columns', None)



def extractEDAFeaturesFromIntradayData(eda_intraday_data, features, time_segment, filter_data_by_segment):
    eda_intraday_features = pd.DataFrame(columns=["local_segment"] + features)

    if not eda_intraday_data.empty:        
        eda_intraday_data = filter_data_by_segment(eda_intraday_data, time_segment)

        if not eda_intraday_data.empty:

            eda_intraday_features = pd.DataFrame()

            # apply a method from calculate features module 
            eda_intraday_features = \
                eda_intraday_data.groupby('local_segment').apply(\
                lambda x: calculateFeatures(convertInputInto2d(x['electrodermal_activity'], x.shape[0]), fs=4, featureNames=features))

            eda_intraday_features.reset_index(inplace=True)

    return eda_intraday_features


def cf_features(sensor_data_files, time_segment, provider, filter_data_by_segment, *args, **kwargs):
    eda_intraday_data = pd.read_csv(sensor_data_files["sensor_data"])

    requested_intraday_features = provider["FEATURES"]
    # name of the features this function can compute
    base_intraday_features_names = gsrFeatureNames
    # the subset of requested features this function can compute
    intraday_features_to_compute = list(set(requested_intraday_features) & set(base_intraday_features_names))

    # extract features from intraday data
    eda_intraday_features = extractEDAFeaturesFromIntradayData(eda_intraday_data,
                                                                    intraday_features_to_compute, time_segment,
                                                                    filter_data_by_segment)

    return eda_intraday_features